# -*- indent-tabs-mode: t -*-

def label_rss_recent_title
	'外部RSSの表示'
end

def label_rss_recent_use_image_link_title
	'画像の扱い'
end

def label_rss_recent_use_image_link_description
	'もしRSSにWebサイトの画像情報が含まれていたら，' +
		'Webサイトへのリンクにテキストではなくその画像を用います．'
end

def label_rss_recent_not_use_image_link
	'リンクに画像を用いない'
end

def label_rss_recent_use_image_link
	'リンクに画像を用いる'
end
