# -*- indent-tabs-mode: t -*-

def label_rss_recent_title
	'External RSS display'
end

def label_rss_recent_use_image_link_title
	'Image treatment'
end

def label_rss_recent_use_image_link_description
	"Select whether you use image as link instead of text or not " +
		"if the RSS has Web site's image information."
end

def label_rss_recent_not_use_image_link
	"don't use image as link"
end

def label_rss_recent_use_image_link
	"use image as link"
end
